==> vlc-1.2.0-pre1.tar.xz: vlc-1.2.0-pre1/modules/stream_filter/dash/xml/DOMHelper.h <==
/*
 * DOMHelper.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef DOMHELPER_H_
#define DOMHELPER_H_

#include <vector>
#include <string>

#include "xml/Node.h"

namespace dash
{
    namespace xml
    {
        class DOMHelper
        {
            public:
                static std::vector<Node *> getElementByTagName      (Node *root, std::string name, bool selfContain);
                static std::vector<Node *> getChildElementByTagName (Node *root, std::string name);

            private:
                static void getElementsByTagName(Node *root, std::string name, std::vector<Node *> *elements, bool selfContain);
        };
    }
}

#endif /* DOMHELPER_H_ */

==> vlc_2.0.5.orig.tar.xz: vlc-2.0.5/modules/stream_filter/dash/xml/DOMHelper.h <==
/*
 * DOMHelper.h
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifndef DOMHELPER_H_
#define DOMHELPER_H_

#include <vector>
#include <string>

#include "xml/Node.h"

namespace dash
{
    namespace xml
    {
        class DOMHelper
        {
            public:
                static std::vector<Node *> getElementByTagName      (Node *root, const std::string& name, bool selfContain);
                static std::vector<Node *> getChildElementByTagName (Node *root, const std::string& name);
                static Node*               getFirstChildElementByName( Node *root, const std::string& name );

            private:
                static void getElementsByTagName(Node *root, const std::string& name, std::vector<Node *> *elements, bool selfContain);
        };
    }
}

#endif /* DOMHELPER_H_ */
